(_api_forward_model)=
# Forward Model

## Base Class
```{eval-rst}
.. autosummary::
    :toctree: generated/

    skretrieval.retrieval.ForwardModel

```

## Available Forward Models
```{eval-rst}
.. autosummary::
    :toctree: generated/

    skretrieval.retrieval.forwardmodel.IdealViewingSpectrograph

```

## Mixins
```{eval-rst}
.. autosummary::
    :toctree: generated/

    skretrieval.retrieval.forwardmodel.IdealViewingMixin
    skretrieval.retrieval.forwardmodel.SpectrometerMixin
```
